==> huaweicloudsdkfunctiongraph-3.0.92-py2.py3-none-any.whl: huaweicloudsdkfunctiongraph/v2/model/show_event_request.py <==
# coding: utf-8

import re
import six



from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ShowEventRequest:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'event_id': 'str',
        'function_urn': 'str'
    }

    attribute_map = {
        'event_id': 'event_id',
        'function_urn': 'function_urn'
    }

    def __init__(self, event_id=None, function_urn=None):
        """ShowEventRequest

        The model defined in huaweicloud sdk

        :param event_id: 事件ID。
        :type event_id: str
        :param function_urn: 函数的URN（Uniform Resource Name），唯一标识函数。
        :type function_urn: str
        """
        
        

        self._event_id = None
        self._function_urn = None
        self.discriminator = None

        self.event_id = event_id
        self.function_urn = function_urn

    @property
    def event_id(self):
        """Gets the event_id of this ShowEventRequest.

        事件ID。

        :return: The event_id of this ShowEventRequest.
        :rtype: str
        """
        return self._event_id

    @event_id.setter
    def event_id(self, event_id):
        """Sets the event_id of this ShowEventRequest.

        事件ID。

        :param event_id: The event_id of this ShowEventRequest.
        :type event_id: str
        """
        self._event_id = event_id

    @property
    def function_urn(self):
        """Gets the function_urn of this ShowEventRequest.

        函数的URN（Uniform Resource Name），唯一标识函数。

        :return: The function_urn of this ShowEventRequest.
        :rtype: str
        """
        return self._function_urn

    @function_urn.setter
    def function_urn(self, function_urn):
        """Sets the function_urn of this ShowEventRequest.

        函数的URN（Uniform Resource Name），唯一标识函数。

        :param function_urn: The function_urn of this ShowEventRequest.
        :type function_urn: str
        """
        self._function_urn = function_urn

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ShowEventRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkfunctiongraph-3.0.105-py2.py3-none-any.whl: huaweicloudsdkfunctiongraph/v2/model/show_event_request.py <==
# coding: utf-8

import re
import six



from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ShowEventRequest:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'function_urn': 'str',
        'event_id': 'str'
    }

    attribute_map = {
        'function_urn': 'function_urn',
        'event_id': 'event_id'
    }

    def __init__(self, function_urn=None, event_id=None):
        """ShowEventRequest

        The model defined in huaweicloud sdk

        :param function_urn: 函数的URN，详细解释见FunctionGraph函数模型的描述。
        :type function_urn: str
        :param event_id: 测试事件ID
        :type event_id: str
        """
        
        

        self._function_urn = None
        self._event_id = None
        self.discriminator = None

        self.function_urn = function_urn
        self.event_id = event_id

    @property
    def function_urn(self):
        """Gets the function_urn of this ShowEventRequest.

        函数的URN，详细解释见FunctionGraph函数模型的描述。

        :return: The function_urn of this ShowEventRequest.
        :rtype: str
        """
        return self._function_urn

    @function_urn.setter
    def function_urn(self, function_urn):
        """Sets the function_urn of this ShowEventRequest.

        函数的URN，详细解释见FunctionGraph函数模型的描述。

        :param function_urn: The function_urn of this ShowEventRequest.
        :type function_urn: str
        """
        self._function_urn = function_urn

    @property
    def event_id(self):
        """Gets the event_id of this ShowEventRequest.

        测试事件ID

        :return: The event_id of this ShowEventRequest.
        :rtype: str
        """
        return self._event_id

    @event_id.setter
    def event_id(self, event_id):
        """Sets the event_id of this ShowEventRequest.

        测试事件ID

        :param event_id: The event_id of this ShowEventRequest.
        :type event_id: str
        """
        self._event_id = event_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ShowEventRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
